@@ -172,18 +172,33 @@ def VIEWS(app):
 \treturn JsonResponse({{{responses}}})
 
 """)
-# removed for beta
-# \t#### Add Your Logic Here ####
-# \tif request.method == '{req.get('method')}':
-# \t\t\treturn JsonResponse({{
-# \t\t\t\t{responses}
-# \t\t\t}}, safe=False)
-# \t\texcept Exception as e:
-# \t\t\treturn JsonResponse(False, safe=False)
-# \treturn JsonResponse(False, safe=False)
+
     return '\n'.join(defs)
 
 
+def DEF(endpoint):
+    misc = endpoint['misc']
+    req = endpoint['request']
+    response = endpoint.get('response')
+    responses = ''.join([f'"{k}": "{v}",' for k, v in response.items()]) if len(response.items()) > 0 else ''
+    csrf = '@csrf_exempt\n' if req.get('host') == 'localhost' else ''
+    header_code = '\theaders = request.headers' if len(endpoint.get('headers').get('body').items()) > 0 else ''
+    params_code = '\n\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 and header_code != '' else '\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 and header_code == '' else ''
+    body_code = '\n\tbody = json.loads(request.body)' if len(endpoint.get('body').get('payload')) > 0 and (header_code != '' or params_code != '') else '\tbody = json.loads(request.body)' if len(endpoint.get('body').get('payload')) > 0 and params_code == '' else ''
+
+    _def = f"""
+# Name: {endpoint.get('misc').get('name')}
+# Headers: {', '.join([header[0]+'('+header[1]+')' for header in endpoint.get('headers').get('body').values() if header[0] and header[1]])}
+# Params: {', '.join([param[0]+'('+param[1]+')' for param in endpoint.get('params').values() if param[0] and param[1]])}
+# Body: {', '.join([payload[0]+'('+payload[1]+')' for payload in endpoint.get('body').get('payload').values() if payload[0] and payload[1]])}
+{csrf}def {misc.get('token')}(request, *args, **kwargs):
+{header_code}{params_code}{body_code}
+
+\treturn JsonResponse({{{responses}}})\n\n"""
+
+    return _def
+
+
 def BASE_MODELS(app):
     app_name =  app.get('name')
     _class = ""
@@ -195,43 +210,43 @@ def BASE_MODELS(app):
             if type == 'UUIDField':
                 _class += f"\t{field[1]} = models.UUIDField(primary_key=True, unique=True, editable=False, max_length=21, default=uuid.uuid4, auto_created=True"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif type == 'JSONField':
                 _class += f"\t{field[1]} = models.JSONField(default=dict, null={field[5]}, blank={field[6]}, unique={field[8]}"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif type == 'DateTimeField':
                 _class += f"\t{field[1]} = models.DateTimeField(default=timezone.now, null={field[5]}, blank={field[6]}, unique={field[8]}"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif type == 'CharField':
                 _class += f"\t{field[1]} = models.CharField(max_length=255, null={field[5]}, blank={field[6]}, unique={field[8]}"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif type == 'EmailField':
                 _class += f"\t{field[1]} = models.EmailField(max_length=255, null={field[5]}, blank={field[6]}, unique={field[8]}"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif type == 'ImageField':
                 _class += f'\t{field[1]} = models.ImageField(upload_to="{field[3]}", null={field[5]}, blank={field[6]}, unique={field[8]}'
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             elif len(type.split('.')) > 1 and type.split('.')[1] == 'id':
                 _class += f"\t{field[1]} = models.ForeignKey(to={field[2].split('.')[0]}, on_delete=models.SET_NULL, null={field[5]}, blank={field[6]}, unique={field[8]}"
                 _class += f', default="{field[3]}"' if field[3] else ''
-                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += f', verbose_name="{field[4]}"' if field[4] else ''
                 _class += ')\n'
             else:
                 _class += f"\t{field[1]} = models.{type}(null={field[5]}, blank={field[6]}, unique={field[8]})\n"
 
         _class += f'\tclass Meta:\n\t\tapp_label = "clix"'
-        _class += '\n'
+        _class += '\n\n\n'
     
     return f"""import uuid
 from django.db import models
@@ -240,6 +255,7 @@ from django.utils import timezone
 {_class}
 """
 
+
 # preparing to remove due to beta
 def APP_URLS(app):
     endpoints = app['endpoints']
@@ -260,6 +276,7 @@ def ADMIN(app):
 # removed for beta
 # {registers}
 
+
 def REQUIREMENTS():
     return """"""
 
